@@ -16,7 +16,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#ident "$Id: trie.c,v 1.27 2002/12/10 00:08:32 nalin Exp $"
+#ident "$Id: trie.c,v 1.28 2003/02/11 20:21:43 nalin Exp $"
 #include "../config.h"
 #include <sys/types.h>
 #include <assert.h>
@@ -311,7 +311,7 @@ char_class_string_extract(const gunichar *s, size_t length,
 	ret = g_malloc0((len + 1) * sizeof(gunichar));
 	unichar_sncpy(ret, s, len);
 	for (i = 0; i < len; i++) {
-		ret[i] &= ~(VTE_ISO2022_WIDTH_MASK);
+		ret[i] &= ~(VTE_ISO2022_ENCODED_WIDTH_MASK);
 	}
 #ifdef VTE_DEBUG
 	if (_vte_debug_on(VTE_DEBUG_PARSE)) {
